<?php

namespace Pinpoint\Feefo\Block\Product;

use Magento\Framework\View\Element\Template;

/**
 * Class Reviews
 * @package Pinpoint\Feefo\Block\Product
 */
class Reviews extends Template
{
    /**
     * @var \Pinpoint\Feefo\Model\FeefoReview
     */
    protected $feefoReviews;

    /**
     * @var \Magento\Framework\Registry
     */
    protected $registry;

    /**
     * @var \Pinpoint\Feefo\Helper\Data
     */
    protected $feefoHelper;

    /**
     * @var string
     */
    const HIDE_PRODUCT_REVIEWS_CONFIG_PATH = 'pinpoint_feefo/display_settings/product_page_reviews';

    /**
     * Reviews constructor.
     * @param \Pinpoint\Feefo\Model\FeefoReview $feefoReviews
     * @param \Pinpoint\Feefo\Helper\Data $feefoHelper
     * @param \Magento\Framework\Registry $registry
     * @param Template\Context $context
     * @param array $data
     */
    public function __construct(
        \Pinpoint\Feefo\Model\FeefoReview $feefoReviews,
        \Pinpoint\Feefo\Helper\Data $feefoHelper,
        \Magento\Framework\Registry $registry,
        Template\Context $context,
        array $data = []
    ) {
        $this->feefoReviews = $feefoReviews;
        $this->registry = $registry;
        $this->feefoHelper = $feefoHelper;
        parent::__construct($context, $data);
    }

    /**
     * @param null $productSku
     * @param bool $forceUpdate
     * @return mixed|\Pinpoint\Feefo\Model\ResourceModel\FeefoReview\Collection
     */
    public function getProductReviews($productSku = null, $forceUpdate = false)
    {
        return $this->feefoReviews->getProductReviews($productSku, $forceUpdate);
    }

    /**
     * @return int
     */
    public function getReviewCount()
    {
        return $this->feefoReviews->getReviewCount();
    }

    /**
     * @return float|int
     */
    public function getAverageRating()
    {
        return $this->feefoReviews->getAverageRating();
    }

    /**
     * @return mixed
     */
    public function getProduct()
    {
        return $this->registry->registry('current_product');
    }

    /**
     * @return boolean
     */
    public function canShow()
    {
        return $this->feefoHelper->getConfig(self::HIDE_PRODUCT_REVIEWS_CONFIG_PATH);
    }

}