<?php

namespace Pinpoint\Feefo\Controller\Index;

use Magento\Framework\App\Action\Action;
use Magento\Framework\View\Result\PageFactory;
use Magento\Framework\App\Action\Context;

/**
 * Class FeefoSalesOrderFeed
 * @package Pinpoint\Feefo\Controller\Index
 */
class FeefoSalesOrderFeed extends Action
{
    /**
     * @var PageFactory
     */
    protected $pageFactory;

    /**
     * @var \Pinpoint\Feefo\Helper\Data
     */
    protected $feefoHelper;

    /**
     * @var \Magento\Framework\App\Response\Http\FileFactory
     */
    protected $fileFactory;

    /**
     * @var \Magento\Framework\Filesystem\DirectoryList
     */
    protected $directoryList;

    /**
     * @var string
     */
    const IP_RESTRICTION_CONFIG_PATH = 'pinpoint_feefo/feefo_import_settings/allowed_ips';

    /**
     * FeefoSalesOrderFeed constructor.
     * @param \Pinpoint\Feefo\Helper\Data $feefoHelper
     * @param \Magento\Framework\App\Response\Http\FileFactory $fileFactory
     * @param \Magento\Framework\Filesystem\DirectoryList $directoryList
     * @param Context $context
     * @param \Magento\Framework\Controller\Result\RawFactory $resultRawFactory
     */
    public function __construct(
        \Pinpoint\Feefo\Helper\Data $feefoHelper,
        \Magento\Framework\App\Response\Http\FileFactory $fileFactory,
        \Magento\Framework\Filesystem\DirectoryList $directoryList,
        Context $context,
        \Magento\Framework\Controller\Result\RawFactory $resultRawFactory
    ) {
        parent::__construct($context);
        $this->pageFactory = $resultRawFactory;
        $this->feefoHelper = $feefoHelper;
        $this->fileFactory = $fileFactory;
        $this->directoryList = $directoryList;
    }

    /**
     * @return \Magento\Framework\Controller\Result\Raw|\Magento\Framework\View\Result\Page
     */
    public function execute()
    {
        $resultPage = $this->pageFactory->create();

        //check to see IP has been added to the allowed ip addresses
        if ($ips = $this->feefoHelper->getConfig(self::IP_RESTRICTION_CONFIG_PATH)) {
            $ips = explode(",", trim($ips));
            if (!in_array($this->feefoHelper->getRequestIp(), $ips)) {
                $resultPage->setHttpResponseCode(403);
                return $resultPage;
            }
        }

        //load and render sales order xml feed from file
        $filePath = $this->directoryList->getPath('var') . DIRECTORY_SEPARATOR . 'export' . DIRECTORY_SEPARATOR . 'feefo';
        $resultPage->setHeader('Content-Type', 'text/xml');
        $resultPage->setContents(\file_get_contents($filePath . DIRECTORY_SEPARATOR . 'feefo_orders_feed.xml'));

        return $resultPage;
    }
}